;; Generated package description from leaf.el  -*- no-byte-compile: t -*-
(define-package "leaf" "4.5.5.0.20221107.5633" "Simplify your init.el configuration, extended use-package" '((emacs "24.1")) :commit "c37b31cc1f2bf2b3ae31fa9eac234e879fefc29f" :authors '(("Naoya Yamashita" . "conao3@gmail.com")) :maintainer '("Naoya Yamashita" . "conao3@gmail.com") :keywords '("lisp" "settings") :url "https://github.com/conao3/leaf.el")
